pub fn get_job_details(
conn: &Connection,
job_id: &str,
) -> Result<Option<QueueJobDetails>, Error>Expand description
Get a structured view of a job for debugging and UI inspection.
pub fn get_job_details(
conn: &Connection,
job_id: &str,
) -> Result<Option<QueueJobDetails>, Error>Get a structured view of a job for debugging and UI inspection.