mark_failed

Function mark_failed 

pub fn mark_failed(
    conn: &Connection,
    job_id: &str,
    error: &str,
) -> Result<bool, Error>
Mark a job as failed with an error message and set completed_at.

Only transitions jobs that are currently processing. Returns true if the update was applied, false if the job’s status had already changed (e.g., cancelled).